from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.chat_profile import ChatProfile
    from ..models.thread_form import ThreadForm
    from ..models.thread_ui_state import ThreadUIState


T = TypeVar("T", bound="TypesResponse")


@_attrs_define
class TypesResponse:
    """如果使用openapi 生成前端代码，缺少了某些类型，请在这里补充

    Attributes:
        thread_form (Union['ThreadForm', None, Unset]):
        thread_ui_state (Union['ThreadUIState', None, Unset]):
        chat_profile (Union['ChatProfile', None, Unset]):
    """

    thread_form: Union["ThreadForm", None, Unset] = UNSET
    thread_ui_state: Union["ThreadUIState", None, Unset] = UNSET
    chat_profile: Union["ChatProfile", None, Unset] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.chat_profile import ChatProfile
        from ..models.thread_form import ThreadForm
        from ..models.thread_ui_state import ThreadUIState

        thread_form: Union[Dict[str, Any], None, Unset]
        if isinstance(self.thread_form, Unset):
            thread_form = UNSET
        elif isinstance(self.thread_form, ThreadForm):
            thread_form = self.thread_form.to_dict()
        else:
            thread_form = self.thread_form

        thread_ui_state: Union[Dict[str, Any], None, Unset]
        if isinstance(self.thread_ui_state, Unset):
            thread_ui_state = UNSET
        elif isinstance(self.thread_ui_state, ThreadUIState):
            thread_ui_state = self.thread_ui_state.to_dict()
        else:
            thread_ui_state = self.thread_ui_state

        chat_profile: Union[Dict[str, Any], None, Unset]
        if isinstance(self.chat_profile, Unset):
            chat_profile = UNSET
        elif isinstance(self.chat_profile, ChatProfile):
            chat_profile = self.chat_profile.to_dict()
        else:
            chat_profile = self.chat_profile

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if thread_form is not UNSET:
            field_dict["thread_form"] = thread_form
        if thread_ui_state is not UNSET:
            field_dict["thread_ui_state"] = thread_ui_state
        if chat_profile is not UNSET:
            field_dict["chat_profile"] = chat_profile

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.chat_profile import ChatProfile
        from ..models.thread_form import ThreadForm
        from ..models.thread_ui_state import ThreadUIState

        d = src_dict.copy()

        def _parse_thread_form(data: object) -> Union["ThreadForm", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                thread_form_type_0 = ThreadForm.from_dict(data)

                return thread_form_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ThreadForm", None, Unset], data)

        thread_form = _parse_thread_form(d.pop("thread_form", UNSET))

        def _parse_thread_ui_state(data: object) -> Union["ThreadUIState", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                thread_ui_state_type_0 = ThreadUIState.from_dict(data)

                return thread_ui_state_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ThreadUIState", None, Unset], data)

        thread_ui_state = _parse_thread_ui_state(d.pop("thread_ui_state", UNSET))

        def _parse_chat_profile(data: object) -> Union["ChatProfile", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                chat_profile_type_0 = ChatProfile.from_dict(data)

                return chat_profile_type_0
            except:  # noqa: E722
                pass
            return cast(Union["ChatProfile", None, Unset], data)

        chat_profile = _parse_chat_profile(d.pop("chat_profile", UNSET))

        types_response = cls(
            thread_form=thread_form,
            thread_ui_state=thread_ui_state,
            chat_profile=chat_profile,
        )

        types_response.additional_properties = d
        return types_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.input_widget_base_type_type_0 import InputWidgetBaseTypeType0
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.input_widget_base_options_type_0 import InputWidgetBaseOptionsType0


T = TypeVar("T", bound="InputWidgetBase")


@_attrs_define
class InputWidgetBase:
    """输入组件的基类, 对应全段标准 html input 组件

    Attributes:
        id (Union[None, Unset, str]):
        name (Union[None, Unset, str]):
        placeholder (Union[None, Unset, str]):
        label (Union[None, Unset, str]):
        tooltip (Union[None, Unset, str]):
        description (Union[None, Unset, str]):
        type (Union[InputWidgetBaseTypeType0, None, Unset]):  Default: InputWidgetBaseTypeType0.STRING.
        value (Union[None, Unset, str]):
        options (Union['InputWidgetBaseOptionsType0', None, Unset]):
    """

    id: Union[None, Unset, str] = UNSET
    name: Union[None, Unset, str] = UNSET
    placeholder: Union[None, Unset, str] = UNSET
    label: Union[None, Unset, str] = UNSET
    tooltip: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    type: Union[InputWidgetBaseTypeType0, None, Unset] = InputWidgetBaseTypeType0.STRING
    value: Union[None, Unset, str] = UNSET
    options: Union["InputWidgetBaseOptionsType0", None, Unset] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.input_widget_base_options_type_0 import InputWidgetBaseOptionsType0

        id: Union[None, Unset, str]
        if isinstance(self.id, Unset):
            id = UNSET
        else:
            id = self.id

        name: Union[None, Unset, str]
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        placeholder: Union[None, Unset, str]
        if isinstance(self.placeholder, Unset):
            placeholder = UNSET
        else:
            placeholder = self.placeholder

        label: Union[None, Unset, str]
        if isinstance(self.label, Unset):
            label = UNSET
        else:
            label = self.label

        tooltip: Union[None, Unset, str]
        if isinstance(self.tooltip, Unset):
            tooltip = UNSET
        else:
            tooltip = self.tooltip

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        type: Union[None, Unset, str]
        if isinstance(self.type, Unset):
            type = UNSET
        elif isinstance(self.type, InputWidgetBaseTypeType0):
            type = self.type.value
        else:
            type = self.type

        value: Union[None, Unset, str]
        if isinstance(self.value, Unset):
            value = UNSET
        else:
            value = self.value

        options: Union[Dict[str, Any], None, Unset]
        if isinstance(self.options, Unset):
            options = UNSET
        elif isinstance(self.options, InputWidgetBaseOptionsType0):
            options = self.options.to_dict()
        else:
            options = self.options

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if placeholder is not UNSET:
            field_dict["placeholder"] = placeholder
        if label is not UNSET:
            field_dict["label"] = label
        if tooltip is not UNSET:
            field_dict["tooltip"] = tooltip
        if description is not UNSET:
            field_dict["description"] = description
        if type is not UNSET:
            field_dict["type"] = type
        if value is not UNSET:
            field_dict["value"] = value
        if options is not UNSET:
            field_dict["options"] = options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.input_widget_base_options_type_0 import InputWidgetBaseOptionsType0

        d = src_dict.copy()

        def _parse_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        id = _parse_id(d.pop("id", UNSET))

        def _parse_name(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_placeholder(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        placeholder = _parse_placeholder(d.pop("placeholder", UNSET))

        def _parse_label(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        label = _parse_label(d.pop("label", UNSET))

        def _parse_tooltip(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        tooltip = _parse_tooltip(d.pop("tooltip", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_type(data: object) -> Union[InputWidgetBaseTypeType0, None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                type_type_0 = InputWidgetBaseTypeType0(data)

                return type_type_0
            except:  # noqa: E722
                pass
            return cast(Union[InputWidgetBaseTypeType0, None, Unset], data)

        type = _parse_type(d.pop("type", UNSET))

        def _parse_value(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        value = _parse_value(d.pop("value", UNSET))

        def _parse_options(data: object) -> Union["InputWidgetBaseOptionsType0", None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                options_type_0 = InputWidgetBaseOptionsType0.from_dict(data)

                return options_type_0
            except:  # noqa: E722
                pass
            return cast(Union["InputWidgetBaseOptionsType0", None, Unset], data)

        options = _parse_options(d.pop("options", UNSET))

        input_widget_base = cls(
            id=id,
            name=name,
            placeholder=placeholder,
            label=label,
            tooltip=tooltip,
            description=description,
            type=type,
            value=value,
            options=options,
        )

        input_widget_base.additional_properties = d
        return input_widget_base

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .agent_bootstrap import AgentBootstrap
from .agent_chat_message_request import AgentChatMessageRequest
from .agent_view_type import AgentViewType
from .blog_post_create_req import BlogPostCreateReq
from .blog_post_create_response import BlogPostCreateResponse
from .blog_post_detail_response import BlogPostDetailResponse
from .blog_post_item import BlogPostItem
from .blog_post_list_response import BlogPostListResponse
from .blog_post_update_request import BlogPostUpdateRequest
from .blog_post_update_response import BlogPostUpdateResponse
from .body_auth_login_access_token import BodyAuthLoginAccessToken
from .bot_config import BotConfig
from .chat_messages_item import ChatMessagesItem
from .chat_messages_item_artifacts_type_0_item import ChatMessagesItemArtifactsType0Item
from .chat_messages_item_props_type_0 import ChatMessagesItemPropsType0
from .chat_messages_response import ChatMessagesResponse
from .chat_profile import ChatProfile
from .chat_profile_starters_type_0_item import ChatProfileStartersType0Item
from .common_form_data import CommonFormData
from .common_form_field import CommonFormField
from .dash_config import DashConfig
from .dash_nav_item import DashNavItem
from .dash_nav_item_variant_type_0 import DashNavItemVariantType0
from .doc_coll_create import DocCollCreate
from .doc_coll_public import DocCollPublic
from .doc_colls_public import DocCollsPublic
from .get_threads_request import GetThreadsRequest
from .http_validation_error import HTTPValidationError
from .input_widget_base import InputWidgetBase
from .input_widget_base_options_type_0 import InputWidgetBaseOptionsType0
from .input_widget_base_type_type_0 import InputWidgetBaseTypeType0
from .list_site_hosts_response import ListSiteHostsResponse
from .list_site_response import ListSiteResponse
from .message import Message
from .new_password import NewPassword
from .page_meta_author import PageMetaAuthor
from .page_meta_response import PageMetaResponse
from .pagination import Pagination
from .read_file_req import ReadFileReq
from .run_bash_req import RunBashReq
from .search_index_public import SearchIndexPublic
from .search_index_response import SearchIndexResponse
from .search_request import SearchRequest
from .site_create_request import SiteCreateRequest
from .site_host_create_request import SiteHostCreateRequest
from .site_host_create_response import SiteHostCreateResponse
from .site_host_delete_response import SiteHostDeleteResponse
from .site_host_item_public import SiteHostItemPublic
from .site_host_update_request import SiteHostUpdateRequest
from .site_host_update_response import SiteHostUpdateResponse
from .site_item_public import SiteItemPublic
from .site_update_request import SiteUpdateRequest
from .tag_item_public import TagItemPublic
from .tag_list_response import TagListResponse
from .task_form_request import TaskFormRequest
from .task_form_response import TaskFormResponse
from .text_2_image_request import Text2ImageRequest
from .theme import Theme
from .thread_filter import ThreadFilter
from .thread_filter_feedback_type_0 import ThreadFilterFeedbackType0
from .thread_form import ThreadForm
from .thread_ui_state import ThreadUIState
from .token import Token
from .types_response import TypesResponse
from .update_password import UpdatePassword
from .user_register import UserRegister
from .user_update_me import UserUpdateMe
from .validation_error import ValidationError
from .workspace import Workspace

__all__ = (
    "AgentBootstrap",
    "AgentChatMessageRequest",
    "AgentViewType",
    "BlogPostCreateReq",
    "BlogPostCreateResponse",
    "BlogPostDetailResponse",
    "BlogPostItem",
    "BlogPostListResponse",
    "BlogPostUpdateRequest",
    "BlogPostUpdateResponse",
    "BodyAuthLoginAccessToken",
    "BotConfig",
    "ChatMessagesItem",
    "ChatMessagesItemArtifactsType0Item",
    "ChatMessagesItemPropsType0",
    "ChatMessagesResponse",
    "ChatProfile",
    "ChatProfileStartersType0Item",
    "CommonFormData",
    "CommonFormField",
    "DashConfig",
    "DashNavItem",
    "DashNavItemVariantType0",
    "DocCollCreate",
    "DocCollPublic",
    "DocCollsPublic",
    "GetThreadsRequest",
    "HTTPValidationError",
    "InputWidgetBase",
    "InputWidgetBaseOptionsType0",
    "InputWidgetBaseTypeType0",
    "ListSiteHostsResponse",
    "ListSiteResponse",
    "Message",
    "NewPassword",
    "PageMetaAuthor",
    "PageMetaResponse",
    "Pagination",
    "ReadFileReq",
    "RunBashReq",
    "SearchIndexPublic",
    "SearchIndexResponse",
    "SearchRequest",
    "SiteCreateRequest",
    "SiteHostCreateRequest",
    "SiteHostCreateResponse",
    "SiteHostDeleteResponse",
    "SiteHostItemPublic",
    "SiteHostUpdateRequest",
    "SiteHostUpdateResponse",
    "SiteItemPublic",
    "SiteUpdateRequest",
    "TagItemPublic",
    "TagListResponse",
    "TaskFormRequest",
    "TaskFormResponse",
    "Text2ImageRequest",
    "Theme",
    "ThreadFilter",
    "ThreadFilterFeedbackType0",
    "ThreadForm",
    "ThreadUIState",
    "Token",
    "TypesResponse",
    "UpdatePassword",
    "UserRegister",
    "UserUpdateMe",
    "ValidationError",
    "Workspace",
)



from enum import Enum


class InputWidgetBaseTypeType0(str, Enum):
    ARRAY = "array"
    BOOLEAN = "boolean"
    NUMBER = "number"
    OBJECT = "object"
    SELECT = "select"
    SLIDER = "slider"
    STRING = "string"
    SWITCH = "switch"
    TAGS = "tags"
    TEXTAREA = "textarea"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.input_widget_base import InputWidgetBase


T = TypeVar("T", bound="ThreadForm")


@_attrs_define
class ThreadForm:
    """发送Html 表单 向用户询问要执行任务的相关参数

    Attributes:
        inputs (List['InputWidgetBase']):
        open_ (Union[Unset, bool]):  Default: True.
        title (Union[Unset, str]):  Default: ''.
        description (Union[Unset, str]):  Default: ''.
    """

    inputs: List["InputWidgetBase"]
    open_: Union[Unset, bool] = True
    title: Union[Unset, str] = ""
    description: Union[Unset, str] = ""
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        inputs = []
        for inputs_item_data in self.inputs:
            inputs_item = inputs_item_data.to_dict()
            inputs.append(inputs_item)

        open_ = self.open_

        title = self.title

        description = self.description

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "inputs": inputs,
            }
        )
        if open_ is not UNSET:
            field_dict["open"] = open_
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.input_widget_base import InputWidgetBase

        d = src_dict.copy()
        inputs = []
        _inputs = d.pop("inputs")
        for inputs_item_data in _inputs:
            inputs_item = InputWidgetBase.from_dict(inputs_item_data)

            inputs.append(inputs_item)

        open_ = d.pop("open", UNSET)

        title = d.pop("title", UNSET)

        description = d.pop("description", UNSET)

        thread_form = cls(
            inputs=inputs,
            open_=open_,
            title=title,
            description=description,
        )

        thread_form.additional_properties = d
        return thread_form

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.chat_profile_starters_type_0_item import ChatProfileStartersType0Item


T = TypeVar("T", bound="ChatProfile")


@_attrs_define
class ChatProfile:
    """
    Attributes:
        name (str):
        description (str):
        created_at (Union[None, Unset, datetime.datetime]): The date and time the record was created. Field is optional
            and not needed when instantiating a new record. It will be automatically set when the record is created in the
            database.
        updated_at (Union[None, Unset, datetime.datetime]): The date and time the record was updated. Field is optional
            and not needed when instantiating a new record. It will be automatically set when the record is created in the
            database.
        id (Union[Unset, str]):
        icon (Union[None, Unset, str]):
        default (Union[None, Unset, bool]):  Default: False.
        starters (Union[List['ChatProfileStartersType0Item'], None, Unset]):
    """

    name: str
    description: str
    created_at: Union[None, Unset, datetime.datetime] = UNSET
    updated_at: Union[None, Unset, datetime.datetime] = UNSET
    id: Union[Unset, str] = UNSET
    icon: Union[None, Unset, str] = UNSET
    default: Union[None, Unset, bool] = False
    starters: Union[List["ChatProfileStartersType0Item"], None, Unset] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        description = self.description

        created_at: Union[None, Unset, str]
        if isinstance(self.created_at, Unset):
            created_at = UNSET
        elif isinstance(self.created_at, datetime.datetime):
            created_at = self.created_at.isoformat()
        else:
            created_at = self.created_at

        updated_at: Union[None, Unset, str]
        if isinstance(self.updated_at, Unset):
            updated_at = UNSET
        elif isinstance(self.updated_at, datetime.datetime):
            updated_at = self.updated_at.isoformat()
        else:
            updated_at = self.updated_at

        id = self.id

        icon: Union[None, Unset, str]
        if isinstance(self.icon, Unset):
            icon = UNSET
        else:
            icon = self.icon

        default: Union[None, Unset, bool]
        if isinstance(self.default, Unset):
            default = UNSET
        else:
            default = self.default

        starters: Union[List[Dict[str, Any]], None, Unset]
        if isinstance(self.starters, Unset):
            starters = UNSET
        elif isinstance(self.starters, list):
            starters = []
            for starters_type_0_item_data in self.starters:
                starters_type_0_item = starters_type_0_item_data.to_dict()
                starters.append(starters_type_0_item)

        else:
            starters = self.starters

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "description": description,
            }
        )
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if updated_at is not UNSET:
            field_dict["updated_at"] = updated_at
        if id is not UNSET:
            field_dict["id"] = id
        if icon is not UNSET:
            field_dict["icon"] = icon
        if default is not UNSET:
            field_dict["default"] = default
        if starters is not UNSET:
            field_dict["starters"] = starters

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.chat_profile_starters_type_0_item import ChatProfileStartersType0Item

        d = src_dict.copy()
        name = d.pop("name")

        description = d.pop("description")

        def _parse_created_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                created_at_type_0 = isoparse(data)

                return created_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        created_at = _parse_created_at(d.pop("created_at", UNSET))

        def _parse_updated_at(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                updated_at_type_0 = isoparse(data)

                return updated_at_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        updated_at = _parse_updated_at(d.pop("updated_at", UNSET))

        id = d.pop("id", UNSET)

        def _parse_icon(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        icon = _parse_icon(d.pop("icon", UNSET))

        def _parse_default(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        default = _parse_default(d.pop("default", UNSET))

        def _parse_starters(data: object) -> Union[List["ChatProfileStartersType0Item"], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                starters_type_0 = []
                _starters_type_0 = data
                for starters_type_0_item_data in _starters_type_0:
                    starters_type_0_item = ChatProfileStartersType0Item.from_dict(starters_type_0_item_data)

                    starters_type_0.append(starters_type_0_item)

                return starters_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List["ChatProfileStartersType0Item"], None, Unset], data)

        starters = _parse_starters(d.pop("starters", UNSET))

        chat_profile = cls(
            name=name,
            description=description,
            created_at=created_at,
            updated_at=updated_at,
            id=id,
            icon=icon,
            default=default,
            starters=starters,
        )

        chat_profile.additional_properties = d
        return chat_profile

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ThreadUIState")


@_attrs_define
class ThreadUIState:
    """ThreadView 的UI 状态

    Attributes:
        enable_chat (Union[None, Unset, bool]):  Default: False.
        enable_scroll_to_bottom (Union[Unset, bool]):  Default: True.
        title (Union[None, Unset, str]):
        description (Union[None, Unset, str]):
        icons (Union[None, Unset, str]):
        layout (Union[None, Unset, str]):
        theme (Union[None, Unset, str]):
    """

    enable_chat: Union[None, Unset, bool] = False
    enable_scroll_to_bottom: Union[Unset, bool] = True
    title: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    icons: Union[None, Unset, str] = UNSET
    layout: Union[None, Unset, str] = UNSET
    theme: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enable_chat: Union[None, Unset, bool]
        if isinstance(self.enable_chat, Unset):
            enable_chat = UNSET
        else:
            enable_chat = self.enable_chat

        enable_scroll_to_bottom = self.enable_scroll_to_bottom

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        icons: Union[None, Unset, str]
        if isinstance(self.icons, Unset):
            icons = UNSET
        else:
            icons = self.icons

        layout: Union[None, Unset, str]
        if isinstance(self.layout, Unset):
            layout = UNSET
        else:
            layout = self.layout

        theme: Union[None, Unset, str]
        if isinstance(self.theme, Unset):
            theme = UNSET
        else:
            theme = self.theme

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enable_chat is not UNSET:
            field_dict["enableChat"] = enable_chat
        if enable_scroll_to_bottom is not UNSET:
            field_dict["enableScrollToBottom"] = enable_scroll_to_bottom
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if icons is not UNSET:
            field_dict["icons"] = icons
        if layout is not UNSET:
            field_dict["layout"] = layout
        if theme is not UNSET:
            field_dict["theme"] = theme

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()

        def _parse_enable_chat(data: object) -> Union[None, Unset, bool]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, bool], data)

        enable_chat = _parse_enable_chat(d.pop("enableChat", UNSET))

        enable_scroll_to_bottom = d.pop("enableScrollToBottom", UNSET)

        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_icons(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        icons = _parse_icons(d.pop("icons", UNSET))

        def _parse_layout(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        layout = _parse_layout(d.pop("layout", UNSET))

        def _parse_theme(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        theme = _parse_theme(d.pop("theme", UNSET))

        thread_ui_state = cls(
            enable_chat=enable_chat,
            enable_scroll_to_bottom=enable_scroll_to_bottom,
            title=title,
            description=description,
            icons=icons,
            layout=layout,
            theme=theme,
        )

        thread_ui_state.additional_properties = d
        return thread_ui_state

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="SiteItemPublic")


@_attrs_define
class SiteItemPublic:
    """
    Attributes:
        id (str):
        title (Union[None, Unset, str]):
        description (Union[None, Unset, str]):
        keywords (Union[None, Unset, str]):
        author (Union[None, Unset, str]):
        copyright_ (Union[None, Unset, str]):
        created_at (Union[Unset, datetime.datetime]):  Default: isoparse('2024-10-01T08:57:11.945485').
        owner_id (Union[None, Unset, str]):
    """

    id: str
    title: Union[None, Unset, str] = UNSET
    description: Union[None, Unset, str] = UNSET
    keywords: Union[None, Unset, str] = UNSET
    author: Union[None, Unset, str] = UNSET
    copyright_: Union[None, Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = isoparse("2024-10-01T08:57:11.945485")
    owner_id: Union[None, Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id

        title: Union[None, Unset, str]
        if isinstance(self.title, Unset):
            title = UNSET
        else:
            title = self.title

        description: Union[None, Unset, str]
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        keywords: Union[None, Unset, str]
        if isinstance(self.keywords, Unset):
            keywords = UNSET
        else:
            keywords = self.keywords

        author: Union[None, Unset, str]
        if isinstance(self.author, Unset):
            author = UNSET
        else:
            author = self.author

        copyright_: Union[None, Unset, str]
        if isinstance(self.copyright_, Unset):
            copyright_ = UNSET
        else:
            copyright_ = self.copyright_

        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        owner_id: Union[None, Unset, str]
        if isinstance(self.owner_id, Unset):
            owner_id = UNSET
        else:
            owner_id = self.owner_id

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "id": id,
            }
        )
        if title is not UNSET:
            field_dict["title"] = title
        if description is not UNSET:
            field_dict["description"] = description
        if keywords is not UNSET:
            field_dict["keywords"] = keywords
        if author is not UNSET:
            field_dict["author"] = author
        if copyright_ is not UNSET:
            field_dict["copyright"] = copyright_
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if owner_id is not UNSET:
            field_dict["owner_id"] = owner_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id")

        def _parse_title(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        title = _parse_title(d.pop("title", UNSET))

        def _parse_description(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_keywords(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        keywords = _parse_keywords(d.pop("keywords", UNSET))

        def _parse_author(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        author = _parse_author(d.pop("author", UNSET))

        def _parse_copyright_(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        copyright_ = _parse_copyright_(d.pop("copyright", UNSET))

        _created_at = d.pop("created_at", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        def _parse_owner_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        owner_id = _parse_owner_id(d.pop("owner_id", UNSET))

        site_item_public = cls(
            id=id,
            title=title,
            description=description,
            keywords=keywords,
            author=author,
            copyright_=copyright_,
            created_at=created_at,
            owner_id=owner_id,
        )

        site_item_public.additional_properties = d
        return site_item_public

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.dash_nav_item import DashNavItem


T = TypeVar("T", bound="DashConfig")


@_attrs_define
class DashConfig:
    """管理面板的后台配置

    Attributes:
        logo (Union[None, Unset, str]):
        path_prefix (Union[None, Unset, str]):  Default: '/'.
        nav_menus (Union[List['DashNavItem'], None, Unset]):
        login_url (Union[Unset, str]):  Default: '/auth/login'.
        theme (Union[None, Unset, str]):  Default: 'light'.
        layout (Union[None, Unset, str]):  Default: 'default'.
    """

    logo: Union[None, Unset, str] = UNSET
    path_prefix: Union[None, Unset, str] = "/"
    nav_menus: Union[List["DashNavItem"], None, Unset] = UNSET
    login_url: Union[Unset, str] = "/auth/login"
    theme: Union[None, Unset, str] = "light"
    layout: Union[None, Unset, str] = "default"
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        logo: Union[None, Unset, str]
        if isinstance(self.logo, Unset):
            logo = UNSET
        else:
            logo = self.logo

        path_prefix: Union[None, Unset, str]
        if isinstance(self.path_prefix, Unset):
            path_prefix = UNSET
        else:
            path_prefix = self.path_prefix

        nav_menus: Union[List[Dict[str, Any]], None, Unset]
        if isinstance(self.nav_menus, Unset):
            nav_menus = UNSET
        elif isinstance(self.nav_menus, list):
            nav_menus = []
            for nav_menus_type_0_item_data in self.nav_menus:
                nav_menus_type_0_item = nav_menus_type_0_item_data.to_dict()
                nav_menus.append(nav_menus_type_0_item)

        else:
            nav_menus = self.nav_menus

        login_url = self.login_url

        theme: Union[None, Unset, str]
        if isinstance(self.theme, Unset):
            theme = UNSET
        else:
            theme = self.theme

        layout: Union[None, Unset, str]
        if isinstance(self.layout, Unset):
            layout = UNSET
        else:
            layout = self.layout

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if logo is not UNSET:
            field_dict["logo"] = logo
        if path_prefix is not UNSET:
            field_dict["pathPrefix"] = path_prefix
        if nav_menus is not UNSET:
            field_dict["navMenus"] = nav_menus
        if login_url is not UNSET:
            field_dict["loginUrl"] = login_url
        if theme is not UNSET:
            field_dict["theme"] = theme
        if layout is not UNSET:
            field_dict["layout"] = layout

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.dash_nav_item import DashNavItem

        d = src_dict.copy()

        def _parse_logo(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        logo = _parse_logo(d.pop("logo", UNSET))

        def _parse_path_prefix(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        path_prefix = _parse_path_prefix(d.pop("pathPrefix", UNSET))

        def _parse_nav_menus(data: object) -> Union[List["DashNavItem"], None, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                nav_menus_type_0 = []
                _nav_menus_type_0 = data
                for nav_menus_type_0_item_data in _nav_menus_type_0:
                    nav_menus_type_0_item = DashNavItem.from_dict(nav_menus_type_0_item_data)

                    nav_menus_type_0.append(nav_menus_type_0_item)

                return nav_menus_type_0
            except:  # noqa: E722
                pass
            return cast(Union[List["DashNavItem"], None, Unset], data)

        nav_menus = _parse_nav_menus(d.pop("navMenus", UNSET))

        login_url = d.pop("loginUrl", UNSET)

        def _parse_theme(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        theme = _parse_theme(d.pop("theme", UNSET))

        def _parse_layout(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        layout = _parse_layout(d.pop("layout", UNSET))

        dash_config = cls(
            logo=logo,
            path_prefix=path_prefix,
            nav_menus=nav_menus,
            login_url=login_url,
            theme=theme,
            layout=layout,
        )

        dash_config.additional_properties = d
        return dash_config

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
